@@ -50,7 +50,3 @@ T = TypeVar("T")
 
 TEvent = TypeVar("TEvent", bound=ActualOccasion)
 TEntity = TypeVar("TEntity", bound=EnduringObject)
-SEntity = TypeVar("SEntity", bound=EnduringObject)
-
-IterableOfEvents = Iterable[ActualOccasion]
-IterableOfItems = Iterable[NamedTuple]
